@@ -14,7 +14,6 @@ module Network.Wai.Logger.Apache (
 
 import Data.ByteString.Char8 (ByteString)
 import qualified Data.ByteString.Char8 as BS
-import Data.CaseInsensitive (CI)
 import Data.List (find)
 import Data.Maybe (fromMaybe)
 #if MIN_VERSION_base(4,5,0)
@@ -24,7 +23,6 @@ import Data.Monoid (mappend)
 #endif
 import Network.HTTP.Types (Status, statusCode)
 import Network.Wai (Request(..))
-import Network.Wai.Logger.Date
 import Network.Wai.Logger.IP
 import System.Log.FastLogger
 
@@ -42,7 +40,7 @@ data IPAddrSource =
   | FromFallback
 
 -- | Apache style log format.
-apacheLogStr :: IPAddrSource -> ZonedDate -> Request -> Status -> Maybe Integer -> LogStr
+apacheLogStr :: IPAddrSource -> FormattedTime -> Request -> Status -> Maybe Integer -> LogStr
 apacheLogStr ipsrc tmstr req status msize =
       toLogStr (getSourceIP ipsrc req)
   <> " - - ["
